@@ -5,7 +5,7 @@
 *	Created:  Sun Jan 24 20:36:39 PST 1999				      *
 *	Contents: DGPS over ip -- get RTCM signals from a remote tcp source   *
 *									      *
-*	$Id: dgpsip.c,v 1.44 1999/10/14 23:30:26 wolfgang Exp $
+*	$Id: dgpsip.c,v 1.45 2000/03/11 02:33:51 wolfgang Exp $
 ******************************************************************************/
 
 /*
@@ -79,8 +79,12 @@
 #define BUFSZ     (4 * 1024)
 #define NMEABUFSZ (4 * 1024)
 
-#ifndef AF_INET6
-# define AF_INET6 0x6666     /* IP version 6 */
+#ifndef AF_INET6		/* for freebsd 2.1.5 */
+#define AF_INET6 0x6666		/* IP version 6 */
+#endif
+
+#ifndef INADDR_NONE		/* for solaris 5.7 */
+#define INADDR_NONE	0xffffffff
 #endif
 
 int             verbose = 0;
@@ -533,7 +537,7 @@ procstats(int nmeafd,
     static char     nmeabuf[NMEABUFSZ];
     static int      nmeaind = 0,
                     pts = -16,
-                    cutoff = 1;
+                    cutoff = 2;
     static struct llpoint
                     sum = {0.0, 0.0, 0.0},
                     sumdif = {0.0, 0.0, 0.0};
@@ -789,7 +793,9 @@ tcpopen(u_char * host,
     } else {
 	hp = gethostbyname(host);
 	if (hp == NULL) {
+#if HAVE_HERROR			/* for solaris 5.7 */
 	    herror("gethostbyname");
+#endif
 	    return (-1);
 	}
 	bcopy(hp->h_addr, (char *) &rem_sockaddr_in.sin_addr, hp->h_length);
@@ -836,6 +842,10 @@ tcpopen(u_char * host,
 
 #else				/* INET6 */
 
+#ifndef INET6_ADDRSTRLEN	/* for linux */
+#define INET6_ADDRSTRLEN 256
+#endif
+
 static const char *
 sockaddr_ntop(struct sockaddr * sa)
 {
