@@ -1,4 +1,4 @@
-/* $Id: rtcm.c,v 1.10 1999/08/24 20:58:26 wolfgang Exp $  */
+/* $Id: rtcm.c,v 1.11 1999/08/28 00:06:20 wolfgang Exp $  */
 
 /* rtcm.c - decode RTCM SC-104 data from a DGPS beacon receiver */
 
@@ -768,7 +768,8 @@ new_byte(u_char b)
     case 0:
     case 2:
 #ifdef DEBUG
-      fprintf(stderr, "unknown byte type %d\n", b >> DATA_SHIFT);
+	fprintf(stderr, "unknown byte type %d (%d 0x%0x)\n", b >> DATA_SHIFT,
+		b, b);
 #endif
       return;
 
